mirror of
https://github.com/sunnypilot/sunnypilot.git
synced 2026-09-11 04:43:43 +08:00
0e51ecbb7e
version: sunnypilot v2026.003.000 (dev)
date: 2026-09-09T15:43:49
master commit: b255314f5a
16 lines
535 B
Python
16 lines
535 B
Python
# ugh, OS X OpenCL doesn't support half
|
|
from tinygrad.runtime.ops_cl import CLDevice, CLProgram, CLCompiler
|
|
|
|
src = """#pragma OPENCL EXTENSION cl_khr_fp16 : enable
|
|
__kernel void max_half(__global half* data0, const __global half* data1) {
|
|
int gidx0 = get_group_id(0);
|
|
data0[gidx0] = max(data1[gidx0], (half)0.0);
|
|
}"""
|
|
|
|
if __name__ == "__main__":
|
|
dev = CLDevice()
|
|
print("created device")
|
|
lib = CLCompiler(dev, "test").compile(src)
|
|
print("created lib", len(lib))
|
|
prg = CLProgram(dev, "max_half", lib)
|
|
print("created prg") |